@@ -6,7 +6,7 @@
 */
 
 #include "collectiongeneralpage.h"
-#include <Akonadi/Calendar/BlockAlarmsAttribute>
+#include <Akonadi/BlockAlarmsAttribute>
 #include <Akonadi/Collection>
 #include <Akonadi/EntityDisplayAttribute>
 #include <PimCommon/PimUtil>
@@ -80,9 +80,7 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
     }
 }
 
-CollectionGeneralPage::~CollectionGeneralPage()
-{
-}
+CollectionGeneralPage::~CollectionGeneralPage() = default;
 
 void CollectionGeneralPage::load(const Akonadi::Collection &collection)
 {
