@@ -262,6 +262,7 @@ void KOViewManager::connectView(KOrg::BaseView *view)
     connect(view, &BaseView::pasteIncidenceSignal, mMainView, &CalendarView::pasteIncidence);
     connect(view, &BaseView::toggleAlarmSignal, mMainView, &CalendarView::toggleAlarm);
     connect(view, &BaseView::toggleTodoCompletedSignal, mMainView, &CalendarView::toggleTodoCompleted);
+    connect(view, &BaseView::toggleOccurrenceCompletedSignal, mMainView, &CalendarView::toggleOccurrenceCompleted);
     connect(view, &BaseView::copyIncidenceToResourceSignal, mMainView, &CalendarView::copyIncidenceToResource);
     connect(view, &BaseView::moveIncidenceToResourceSignal, mMainView, &CalendarView::moveIncidenceToResource);
     connect(view, &BaseView::dissociateOccurrencesSignal, mMainView, &CalendarView::dissociateOccurrences);
@@ -461,7 +462,7 @@ void KOViewManager::selectWorkWeek()
         QDate date = mMainView->activeDate();
         mMainView->dateNavigator()->selectWorkWeek(date);
     } else {
-        KMessageBox::sorry(mMainView,
+        KMessageBox::error(mMainView,
                            i18n("Unable to display the work week since there are no work days configured. "
                                 "Please properly configure at least 1 work day in the Time and Date preferences."));
     }
